/*
	Relay -- a tool to record and play Quake2 demos
	Copyright (C) 1999 Conor Davis

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

	Conor Davis
	cedavis@epid.org
*/

#ifndef	__UTILS_H
#define	__UTILS_H

extern size_t mstime();
extern char *GamePath(char *dest, char *basedir, char *gamedir);
extern qboolean FileExists(char *filename);
extern int ExpandString(char *dest, int len, char *src, char format[256][32]);

extern int Argc(char *s);
extern char *Argv(char *s, int index);
extern char *Args(char *s);
extern char *SplitCommandString(char *in, char c);

#endif	// __UTILS_H